/*
Copyright 4000 Tester2

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

This file was generated by BlueCat Automation Toolkit (BATK).
Portions which reproduce template contents from BATK are Copyright 2023 BlueCat Networks Inc.
Other contents are owned by their authors.
 */
import { useCallback, useMemo } from 'react';

export default (values, setError, errorText, disable) => {
    const names = useMemo(
        () => values.map(({ id, name }) => ({ id, name: name })),
        [values],
    );
    return useCallback(
        (text) => {
            if (disable) {
                return [];
            }

            const textLower = text.toLowerCase();
            const suggestions = names.filter(({ name }) =>
                name.toLowerCase().includes(textLower)
            );
            if (!suggestions.length) {
                setError(errorText);
                return suggestions;
            }

            return suggestions
                .sort((a, b) => {
                    const an = a.name;
                    const bn = b.name;
                    const as = an.toLowerCase().startsWith(textLower);
                    const bs = bn.toLowerCase().startsWith(textLower);
                    return bs - as || an.localeCompare(bn);
                })
                .map(({ id, name }) => ({ id, name }));
        },
        [names, values, setError, errorText, disable],
    );
};